@@ -1,7 +1,7 @@
 readSourceFlagDefine <- function(Directory, filename= "source_flag_definitions.txt") {
   
   X <- read.delim(file.path(Directory,filename, fsep =.Platform$file.sep), 
-                  skip = 39,                    
+                  comment.char = "%",                    
                   header = FALSE,                 
                   stringsAsFactors= FALSE)
   
